package org.apache.torque.templates.platform;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.templates.typemapping.SqlType;
import org.apache.torque.templates.typemapping.SchemaType;

/**
 * SAP DB Platform implementation.
 *
 * @author <a href="mailto:mpoeschl@marmot.at">Martin Poeschl</a>
 * @version $Id: PlatformSapdbImpl.java 473814 2006-11-11 22:30:30 +0000 (Sat, 11 Nov 2006) tv $
 */
public class PlatformSapdbImpl extends PlatformDefaultImpl
{
    /**
     * Default constructor.
     */
    public PlatformSapdbImpl()
    {
        super();
        initialize();
    }

    /**
     * Initializes db specific domain mapping.
     */
    private void initialize()
    {
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BIT,
                new SqlType("FIXED", "1", "0"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.TINYINT,
                new SqlType("CHAR BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BIGINT,
                new SqlType("FIXED", "38", "0"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.DOUBLE,
                new SqlType("DOUBLE PRECISION"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.NUMERIC,
                new SqlType("DECIMAL"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.LONGVARCHAR,
                new SqlType("LONG VARCHAR"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BINARY,
                new SqlType("CHAR(254) BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.VARBINARY,
                new SqlType("LONG BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.LONGVARBINARY,
                new SqlType("LONG BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.JAVA_OBJECT,
                new SqlType("LONG BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BLOB,
                new SqlType("LONG BYTE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.CLOB,
                new SqlType("LONG UNICODE"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BOOLEANINT,
                new SqlType("SMALLINT"));
        setSchemaTypeToSqlTypeMapping(
                SchemaType.BOOLEANCHAR,
                new SqlType("CHAR"));
    }

    /**
     * @see Platform#getNativeIdMethod()
     */
    public String getNativeIdMethod()
    {
        return Platform.SEQUENCE;
    }

    /**
     * @see Platform#getAutoIncrement()
     */
    public String getAutoIncrement()
    {
        return "DEFAULT SERIAL";
    }

}
