package org.apache.torque.templates.sourcefilter;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.control.ControllerState;
import org.apache.torque.gf.source.SourceElement;
import org.apache.torque.gf.source.filter.SourceFilter;
import org.apache.torque.templates.TorqueSchemaAttributeName;

/**
 * A source filter which returns true if the attribute "interface"
 * is set on the current source element and if the name does not contain
 * a dot.
 *
 * @version $Id: $
 */
public class InterfaceSourceFilter implements SourceFilter
{
    public boolean proceed(ControllerState controllerState)
    {
        SourceElement sourceElement = controllerState.getSourceElement();
        String interfaceName
                = (String) sourceElement.getAttribute(
                        TorqueSchemaAttributeName.INTERFACE.getName());
        if (interfaceName == null)
        {
            return false;
        }
        boolean containsDot = interfaceName.indexOf('.') != -1;
        return !containsDot;
    }
}
