package org.apache.torque.templates.transformer.om;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.control.ControllerState;
import org.apache.torque.gf.source.SourceElement;
import org.apache.torque.gf.source.transform.SourceTransformerException;
import org.apache.torque.templates.TorqueSchemaAttributeName;
import org.apache.torque.templates.TorqueSchemaElementName;

/**
 * Transforms an Inheritance element.
 */
public class OMInheritanceTransformer
{
    private static final String INPUT_KEY_ATTRIBUTE = "key";
    private static final String CLASSKEY_CONSTANT_ATTRIBUTE = "classkeyConstant";
    private static final String CLASSNAME_CONSTANT_ATTRIBUTE = "classnameConstant";
    private static final String CLASS_CONSTANT_ATTRIBUTE = "classConstant";
    private static final String CLASS_NAME_ATTRIBUTE = "className";
    private static final String PACKAGE_ATTRIBUTE = "package";
    private static final String BEAN_PACKAGE_ATTRIBUTE = "beanPackage";
    private static final String BEAN_EXTENDS_ATTRIBUTE = "beanExtends";
    private static final String BEAN_CLASS_NAME_ATTRIBUTE = "beanClassName";

    public void transform(
            SourceElement inheritanceElement,
            ControllerState controllerState)
        throws SourceTransformerException
    {
        if (!TorqueSchemaElementName.INHERITANCE.getName().equals(
                inheritanceElement.getName()))
        {
            throw new IllegalArgumentException("Illegal element Name "
                    + inheritanceElement.getName());
        }
        String key = (String)
                inheritanceElement.getAttribute(INPUT_KEY_ATTRIBUTE);
        if (key == null)
        {
            throw new IllegalArgumentException(
                    "Attribute \"key\" not set in Element "
                        + TorqueSchemaElementName.INHERITANCE.getName());
        }
        inheritanceElement.setAttribute(
                CLASSKEY_CONSTANT_ATTRIBUTE, "CLASSKEY_" + key.toUpperCase());
        inheritanceElement.setAttribute(
                CLASSNAME_CONSTANT_ATTRIBUTE, "CLASSNAME_" + key.toUpperCase());
        inheritanceElement.setAttribute(
                CLASS_CONSTANT_ATTRIBUTE, "CLASS_" + key.toUpperCase());

        SourceElement tableElement
                = inheritanceElement.getParent().getParent();
        String className = (String)inheritanceElement.getAttribute(
                TorqueSchemaAttributeName.CLASS.getName());
        if (className == null)
        {
            className = (String) tableElement.getAttribute(
                    TableAttributeName.DB_OBJECT_CLASS_NAME);
        }
        inheritanceElement.setAttribute(
                CLASS_NAME_ATTRIBUTE, className);
        inheritanceElement.setAttribute(
                PACKAGE_ATTRIBUTE,
                tableElement.getAttribute(
                        TableAttributeName.DB_OBJECT_PACKAGE));
        {
            String extendsAttribute = (String) inheritanceElement.getAttribute(
                    TorqueSchemaAttributeName.EXTENDS.getName());
            String beanExtends = (String) inheritanceElement.getAttribute(
                    BEAN_EXTENDS_ATTRIBUTE);
            if (extendsAttribute == null)
            {
                extendsAttribute = (String) tableElement.getAttribute(
                        TableAttributeName.DB_OBJECT_CLASS_NAME);
                inheritanceElement.setAttribute(
                        TorqueSchemaAttributeName.EXTENDS.getName(),
                        extendsAttribute);
                inheritanceElement.setAttribute(
                        BEAN_EXTENDS_ATTRIBUTE,
                        tableElement.getAttribute(
                                TableAttributeName.BEAN_CLASS_NAME));
            }
            else if (beanExtends == null)
            {
                // we try to guess the extendsBean from extends
                // and the bean package
                int lastDot = extendsAttribute.lastIndexOf(".");
                String unqualifiedClassname;
                if (lastDot != -1)
                {
                    unqualifiedClassname
                            = extendsAttribute.substring(lastDot + 1);
                }
                else
                {
                    unqualifiedClassname = extendsAttribute;
                }
                beanExtends = controllerState.getOption(
                            "torque.om.className.beanClassNamePrefix")
                        + unqualifiedClassname
                        + controllerState.getOption(
                            "torque.om.className.beanClassNameSuffix");
                inheritanceElement.setAttribute(
                        BEAN_EXTENDS_ATTRIBUTE,
                        beanExtends);
            }
        }
        {
            int lastDot = className.lastIndexOf(".");
            String unqualifiedClassname;
            if (lastDot != -1)
            {
                unqualifiedClassname
                        = className.substring(lastDot + 1);
            }
            else
            {
                unqualifiedClassname = className;
            }
            String beanClassName = controllerState.getOption(
                        "torque.om.className.beanClassNamePrefix")
                    + unqualifiedClassname
                    + controllerState.getOption(
                        "torque.om.className.beanClassNameSuffix");
            inheritanceElement.setAttribute(
                    BEAN_CLASS_NAME_ATTRIBUTE,
                    beanClassName);

        }
        inheritanceElement.setAttribute(
                BEAN_PACKAGE_ATTRIBUTE,
                tableElement.getAttribute(
                        TableAttributeName.BEAN_PACKAGE));
    }
 }
