package org.apache.torque.templates.transformer.om.dbobject.base;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.InputStreamReader;

import org.apache.torque.gf.control.ControllerState;
import org.apache.torque.gf.source.SourceElement;
import org.apache.torque.gf.source.transform.AttributeTransformer;
import org.apache.torque.gf.source.transform.SourceTransformerException;
import org.apache.torque.templates.TemplateOptionName;
import org.apache.torque.templates.TorqueSchemaAttributeName;
import org.apache.torque.templates.TorqueSchemaElementName;

public class BaseDbObjectTableTransformer extends AttributeTransformer
{
    public BaseDbObjectTableTransformer() throws SourceTransformerException
    {
        super(new InputStreamReader(
                BaseDbObjectTableTransformer.class
                   .getResourceAsStream(
                        "BaseDbObjectTableTransformer.properties")));
    }


    public SourceElement transform(
            SourceElement tableElement,
            ControllerState controllerState)
        throws SourceTransformerException
    {
        if (!TorqueSchemaElementName.TABLE.getName().equals(
                tableElement.getName()))
        {
            throw new IllegalArgumentException("Illegal element Name "
                    + tableElement.getName());
        }

        setBaseClass(tableElement, controllerState);
        return super.transform(tableElement, controllerState);
    }

    /**
     * Sets the base class attribute on the table element if it is not
     * already set.
     *
     * @param tableElement the table attribute to process, not null.
     * @param controllerState the controller state, not null.
     */
    private void setBaseClass(
            SourceElement tableElement,
            ControllerState controllerState)
    {
        Object baseClass = tableElement.getAttribute(
                TorqueSchemaAttributeName.BASE_CLASS);
        if (baseClass == null)
        {
            baseClass = tableElement.getParent().getAttribute(
                    TorqueSchemaAttributeName.BASE_CLASS);
        }
        if (baseClass == null)
        {
            baseClass = controllerState.getOption(
                    TemplateOptionName.OM_DB_OBJECT_DEFAULT_BASE_CLASS);
        }
        if (baseClass == null)
        {
            baseClass = "";
        }
        tableElement.setAttribute(
                TorqueSchemaAttributeName.BASE_CLASS,
                baseClass);
    }
 }
