package org.apache.torque.templates.transformer.om.mapInit;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.InputStreamReader;

import org.apache.torque.gf.control.ControllerState;
import org.apache.torque.gf.processor.string.Camelbacker;
import org.apache.torque.gf.source.SourceElement;
import org.apache.torque.gf.source.transform.AttributeTransformer;
import org.apache.torque.gf.source.transform.SourceTransformerException;
import org.apache.torque.templates.TemplateOptionName;
import org.apache.torque.templates.TorqueSchemaAttributeName;
import org.apache.torque.templates.TorqueSchemaElementName;
import org.apache.torque.templates.transformer.om.DatabaseAttributeName;

public class MapInitDatabaseTransformer  extends AttributeTransformer
{
    private static Camelbacker camelbacker = new Camelbacker();

    public MapInitDatabaseTransformer() throws SourceTransformerException
    {
        super(new InputStreamReader(
                MapInitDatabaseTransformer.class
                   .getResourceAsStream(
                        "MapInitDatabaseTransformer.properties")));
    }

    public SourceElement transform(
            SourceElement databaseElement,
            ControllerState controllerState)
        throws SourceTransformerException
    {
        if (!TorqueSchemaElementName.DATABASE.getName().equals(
                databaseElement.getName()))
        {
            throw new IllegalArgumentException("Illegal element Name "
                    + databaseElement.getName());
        }
        String name = (String) databaseElement.getAttribute(
                TorqueSchemaAttributeName.NAME.getName());
        if (name == null)
        {
            throw new SourceTransformerException("The attribute "
                    + TorqueSchemaAttributeName.NAME.getName()
                    + " on element "
                    + databaseElement.getName()
                    + " is null");
        }
        String mapInitClassName
                = controllerState.getOption(
                        TemplateOptionName.OM_MAP_INIT_CLASS_NAME_PREFIX)
                    + camelbacker.process(name)
                    + controllerState.getOption(
                        TemplateOptionName.OM_MAP_INIT_CLASS_NAME_SUFFIX);
        databaseElement.setAttribute(
                DatabaseAttributeName.MAP_INIT_CLASS_NAME,
                mapInitClassName);
        super.transform(databaseElement, controllerState);
        return databaseElement;
    }
 }
