package org.apache.torque.templates.typemapping;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


public enum JavaType
{
    STRING("String", false, false, null),
    BIG_DECIMAL("BigDecimal", false, true, "java.math."),
    BOOLEAN_PRIMITIVE("boolean", true, false, null),
    BOOLEAN_OBJECT("Boolean", false, false, null),
    BYTE_PRIMITIVE("byte", true, true, null),
    BYTE_OBJECT("Byte", false, true, null),
    SHORT_PRIMITIVE("short", true, true, null),
    SHORT_OBJECT("Short", false, true, null),
    INTEGER_PRIMITIVE("int", true, true, null),
    INTEGER_OBJECT("Integer", false, true, null),
    LONG_PRIMITIVE("long", true, true, null),
    LONG_OBJECT("Long", false, true, null),
    FLOAT_PRIMITIVE("float", true, true, null),
    FLOAT_OBJECT("Float", false, true, null),
    DOUBLE_PRIMITIVE("double", true, true, null),
    DOUBLE_OBJECT("Double", false, true, null),
    CHAR_PRIMITIVE("char", true, false, null),
    CHAR_OBJECT("Char", false, false, null),
    BYTE_PRIMITIVE_ARRAY("byte[]", false, false, null),
    DATE("java.util.Date", false, false, null);

    private String className;

    private boolean primitive;

    private boolean number;

    private String packagePrefix;

    private JavaType(
            String className,
            boolean primitive,
            boolean number,
            String packagePrefix)
    {
        this.className = className;
        this.primitive = primitive;
        this.number = number;
        this.packagePrefix = packagePrefix;
    }

    public boolean isPrimitive()
    {
        return primitive;
    }

    public boolean isNumber()
    {
        return number;
    }

    public String getClassName()
    {
        return className;
    }

    public String getPackagePrefix()
    {
        return packagePrefix;
    }

    public String getFullClassName()
    {
        if (packagePrefix == null)
        {
            return className;
        }
        else
        {
            return packagePrefix + className;
        }
    }


}
