package org.apache.torque.templates;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.torque.gf.configuration.UnitDescriptor;
import org.apache.torque.gf.configuration.option.MapOptionsConfiguration;
import org.apache.torque.gf.configuration.paths.CustomProjectPaths;
import org.apache.torque.gf.configuration.paths.DefaultTorqueGfPaths;
import org.apache.torque.gf.configuration.paths.Maven2DirectoryProjectPaths;
import org.apache.torque.gf.control.Controller;
import org.junit.Test;

public class TestProcessing
{
    @Test
    public void testProcessSchemaXml() throws Exception
    {
        Controller controller = new Controller();
        List<UnitDescriptor> unitDescriptors = new ArrayList<UnitDescriptor>();
        Map<String, String> overrideOptions = new HashMap<String, String>();
        overrideOptions.put("torque.database", "mysql");
        overrideOptions.put("torque.om.package", "org.apache.torque.test");

        // om templates
        CustomProjectPaths projectPaths
                = new CustomProjectPaths(
                    new Maven2DirectoryProjectPaths(new File(".")));
        projectPaths.setConfigurationDir(
                new File("src/main/resources/org/apache/torque/templates/om"));
        projectPaths.setSourceDir(
                new File("src/test/schema"));
        projectPaths.setModifiedFileTargetDir(
                new File("target/generated-sources-2"));
        unitDescriptors.add(new UnitDescriptor(
                UnitDescriptor.Packaging.DIRECTORY,
                projectPaths,
                new DefaultTorqueGfPaths(),
                null,
                new MapOptionsConfiguration(overrideOptions),
                null));

        // sql templates
        projectPaths
                = new CustomProjectPaths(
                    new Maven2DirectoryProjectPaths(new File(".")));
        projectPaths.setConfigurationDir(
                new File("src/main/resources/org/apache/torque/templates/sql"));
        projectPaths.setSourceDir(
                new File("src/test/schema"));
        projectPaths.setNewFileTargetDir(
                new File("target/generated-sql"));
        projectPaths.setModifiedFileTargetDir(
                new File("target/generated-sql-2"));
        unitDescriptors.add(new UnitDescriptor(
                UnitDescriptor.Packaging.DIRECTORY,
                projectPaths,
                new DefaultTorqueGfPaths(),
                null,
                new MapOptionsConfiguration(overrideOptions),
                null));

        // idbroker-init-sql templates
        projectPaths
                = new CustomProjectPaths(
                    new Maven2DirectoryProjectPaths(new File(".")));
        projectPaths.setConfigurationDir(
                new File("src/main/resources/org/apache/torque/templates/idtable"));
        projectPaths.setSourceDir(
                new File("src/test/schema"));
        projectPaths.setNewFileTargetDir(
                new File("target/generated-sql"));
        projectPaths.setModifiedFileTargetDir(
                new File("target/generated-sql-2"));
        unitDescriptors.add(new UnitDescriptor(
                UnitDescriptor.Packaging.DIRECTORY,
                projectPaths,
                new DefaultTorqueGfPaths(),
                null,
                new MapOptionsConfiguration(overrideOptions),
                null));

        // html doc templates
        projectPaths = new CustomProjectPaths(
                    new Maven2DirectoryProjectPaths(new File(".")));
        projectPaths.setConfigurationDir(
                new File("src/main/resources/org/apache/torque/templates/doc/html"));
        projectPaths.setSourceDir(
                new File("src/test/schema"));
        projectPaths.setNewFileTargetDir(
                new File("target/generated-docs"));
        projectPaths.setModifiedFileTargetDir(
                new File("target/generated-docs-2"));
        unitDescriptors.add(new UnitDescriptor(
                UnitDescriptor.Packaging.DIRECTORY,
                projectPaths,
                new DefaultTorqueGfPaths(),
                null,
                new MapOptionsConfiguration(overrideOptions),
                null));

        // xdoc doc templates
        projectPaths = new CustomProjectPaths(
                new Maven2DirectoryProjectPaths(new File(".")));
        projectPaths.setConfigurationDir(
                new File("src/main/resources/org/apache/torque/templates/doc/xdoc"));
        projectPaths.setSourceDir(
                new File("src/test/schema"));
        projectPaths.setNewFileTargetDir(
                new File("target/generated-xdocs"));
        projectPaths.setModifiedFileTargetDir(
                new File("target/generated-xdocs-2"));
        unitDescriptors.add(new UnitDescriptor(
                UnitDescriptor.Packaging.DIRECTORY,
                projectPaths,
                new DefaultTorqueGfPaths(),
                null,
                new MapOptionsConfiguration(overrideOptions),
                null));

        // generate
        controller.run(unitDescriptors);
    }
}
