package org.apache.torque.gf.configuration;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.HashSet;
import java.util.Set;

import org.apache.torque.gf.configuration.mergepoint.ActionSaxHandlerFactories;
import org.apache.torque.gf.configuration.mergepoint.OptionsSaxHandlerFactories;
import org.apache.torque.gf.source.SourceType;
import org.apache.torque.gf.source.properties.PropertiesSourceType;
import org.apache.torque.gf.source.xml.XmlSourceType;

/**
 * Contains the required handlers for reading the configuration.
 *
 * $Id: $
 */
public class ConfigurationHandlers
{
    /**
     * The known types of generators and how to read their configuration.
     */
    private GeneratorTypes generatorTypes = new GeneratorTypes();

    /**
     * The known types of source types.
     */
    private Set<SourceType> sourceTypes = new HashSet<SourceType>();

    /**
     * The known types of mergepoint action handlers.
     */
    private ActionSaxHandlerFactories actionSaxHandlerFactories
            = new ActionSaxHandlerFactories();

    /**
     * The known types of options.
     */
    private OptionsSaxHandlerFactories optionsSaxHandlerFactories
            = new OptionsSaxHandlerFactories();

    /**
     * Standard constructor.
     */
    public ConfigurationHandlers()
    {
        sourceTypes.add(new XmlSourceType());
        sourceTypes.add(new PropertiesSourceType());
    }

    /**
     * Returns the known generator types.
     *
     * @return the known generator types.
     */
    public GeneratorTypes getGeneratorTypes()
    {
        return generatorTypes;
    }

    /**
     * Returns the known source types.
     *
     * @return the known source types.
     */
    public Set<SourceType> getSourceTypes()
    {
        return sourceTypes;
    }

    /**
     * Returns the known mergepoint action handlers.
     *
     * @return the known mergepoint action handlers.
     */
    public ActionSaxHandlerFactories getActionSaxHandlerFactories()
    {
        return actionSaxHandlerFactories;
    }

    /**
     * Returns the known options handlers.
     *
     * @return the known options handlers.
     */
    public OptionsSaxHandlerFactories getOptionsSaxHandlerFactories()
    {
        return optionsSaxHandlerFactories;
    }
}
