package org.apache.torque.gf.configuration.controller;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.qname.Namespace;
import org.apache.torque.gf.qname.QualifiedName;

/**
 * Represents a reference to a generator.
 *
 * @version $Id: XmlToAppData.java 239626 2005-08-24 12:19:51Z henning $
 */
public class GeneratorReference
{
    /** The name of the referenced generator. */
    private QualifiedName name;

    /**
     * The namespace under which the generator should execute.
     * Defaults to the namespace in the generator's name.
     */
    private Namespace namespace;

    /**
     * Constructor.
     *
     * @param name the name of the referenced generator, not null.
     */
    public GeneratorReference(String name)
    {
        if (name == null)
        {
            throw new IllegalArgumentException("name must not be null");
        }
        this.name = new QualifiedName(name, Namespace.ROOT_NAMESPACE);
        namespace = this.name.getNamespace();
    }

    /**
     * Constructor.
     *
     * @param name the name of the referenced generator, not null.
     */
    public GeneratorReference(QualifiedName name)
    {
        if (name == null)
        {
            throw new IllegalArgumentException("name must not be null");
        }
        this.name = name;
        namespace = this.name.getNamespace();
    }

    /**
     * Returns the qualified name of the generator.
     *
     * @return the qualified name of the generator, not null.
     */
    public QualifiedName getName()
    {
        return name;
    }

    /**
     * Returns the namespace under which the generator executes.
     *
     * @return the namespace under which the generator executes.
     */
    public Namespace getNamespace()
    {
        return namespace;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString()
    {
        StringBuffer result = new StringBuffer();
        result.append("(name=").append(name).append(")");
        return result.toString();
    }
}
