package org.apache.torque.gf.configuration.generator;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.configuration.ConfigurationHandlers;
import org.apache.torque.gf.configuration.ConfigurationProvider;
import org.apache.torque.gf.configuration.paths.ProjectPaths;
import org.apache.torque.gf.qname.QualifiedName;
import org.xml.sax.SAXException;

/**
 * Creates Java generator SAX handlers.
 */
public class JavaGeneratorSaxHandlerFactory
        implements GeneratorSaxHandlerFactory
{
    /**
     * The type of the generators which can be processed by the
     * GeneratorSaxHandlers created by this factory.
     */
    private static final String GENERATOR_TYPE = "javaGenerator";

    /**
     * Returns the generator type which can be handled by the
     * GeneratorSaxHandlers created by this factory.
     * @return "javaGenerator".
     */
    public String getType()
    {
        return GENERATOR_TYPE;
    }

    /**
     * Returns a JavaGeneratorSaxHandler for reading the configuration of
     * Java generators. This implementation uses the provided name
     * as generator name.
     *
     * @param generatorName the name for the generator which configuration
     *        will be read in by the generated SaxHandlerFactory,
     *        or null if the name of the generator should be determined from
     *        the parsed XML.
     * @param configurationProvider The access object for the configuration
     *        files, not null.
     * @param projectPaths The paths of the surrounding project, not null.
     * @param configurationHandlers the available configuration handlers,
     *        not null.
     *
     * @return a new JavaGeneratorSaxHandler.
     */
    public final GeneratorSaxHandler getGeneratorSaxHandler(
            QualifiedName generatorName,
            ConfigurationProvider configurationProvider,
            ProjectPaths projectPaths,
            ConfigurationHandlers configurationHandlers)
         throws SAXException
    {
        return new JavaGeneratorSaxHandler(
                generatorName,
                configurationProvider,
                projectPaths,
                configurationHandlers);
    }
}
