package org.apache.torque.gf.configuration.paths;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * The default organization of the torque-gf directory.
 * This is:<br/>
 * - torque-gf root<br/>
 * - - conf<br/>
 * - - - control.xml<br/>
 * - - generatorDefs<br/>
 * - - templates<br/>
 */
public class DefaultTorqueGfPaths implements TorqueGfPaths
{
    /**
     * The path to the control configuration file, relative to the
     * configuration directory.
     */
    private static final String CONTROL_CONFIGURATION_FILE_NAME
        = "control.xml";

    /**
     * The path to the template directory, relative to the torque-gf directory.
     */
    private static final String TEMPLATES_DIRECTORY = "templates";

    /**
     * The path to the configuration directory, relative to the
     * torque-gf directory.
     */
    private static final String CONFIGURATION_DIRECTORY = "conf";

    /**
     * The path to the generator definitions directory, relative to the
     * configuration root directory.
     */
    private static final String GENERATOR_DEFS_DIRECTORY
        = "generatorDefs";

    public String getControlConfigurationFile()
    {
        return CONTROL_CONFIGURATION_FILE_NAME;
    }

    public String getTemplateSubdirectory()
    {
        return TEMPLATES_DIRECTORY;
    }

    public String getConfigurationDirectory()
    {
        return CONFIGURATION_DIRECTORY;
    }

    public String getGeneratorDefDirectory()
    {
        return GENERATOR_DEFS_DIRECTORY;
    }
}
