package org.apache.torque.gf.configuration.paths;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

/**
 * Provides the default paths which the code generator needs to interact with
 * its surrounding project.
 * "Default" means that the settings can be overridden in a unit of generation.
 * NB: This object does not contain any information about how the code generator
 * configuration is organized internally.
 */
public interface ProjectPaths
{
    /**
     * Returns the path to the generator configuration directory.
     * The path must either be absolute or relative to the current working
     * directory.
     *
     * @return the path to the generator configuration; may (but must not)
     *         be null if no configuration is contained in the surrounding
     *         project; must be null if the configuration is read from the
     *         class path.
     */
    File getConfigurationPath();

    /**
     * Returns the package of the generator configuration.
     *
     * @return the package to the generator configuration. Must be null
     *         if the configuration is read from the file system or from
     *         a jar file. Must not be null if the configuration is read
     *         from the class path.
     */
    String getConfigurationPackage();

    /**
     * Returns the path to the default source directory for the generator.
     * The path must either be absolute or relative to the current working
     * directory.
     * "Default" means that the setting
     * can be overridden in a unit of generation. This usually points to a
     * subdirectory where the sources are located.
     *
     * @return the path for the source files, not null.
     */
    File getDefaultSourcePath();

    /**
     * Returns the path to the default directory for the generated output
     * if the generated output is created anew each time.
     * The path must either be absolute or relative to the current working
     * directory.
     *
     * @return the path for the generated files, not null.
     */
    File getNewFileTargetPath();

    /**
     * Returns the path to the default directory for the generated output
     * if the generated output is not created anew each time.
     * The path must either be absolute or relative to the current working
     * directory.
     *
     * @return the path for the generated files, not null.
     */
    File getModifiedFileTargetPath();
}
