package org.apache.torque.gf.generator.java;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.configuration.ConfigurationException;
import org.apache.torque.gf.configuration.mergepoint.MergepointMapping;
import org.apache.torque.gf.generator.GeneratorImpl;
import org.apache.torque.gf.qname.QualifiedName;

/**
 * A generator without mergepoints.
 */
public abstract class GeneratorWithoutMergepoints extends GeneratorImpl
{
    /**
     * Constructs a GeneratorWithoutMergepoints with the given name.
     *
     * @param name the name of this generator, not null.
     *
     * @throws NullPointerException if name is null.
     */
    public GeneratorWithoutMergepoints(QualifiedName name)
    {
        super(name);
    }

    @Override
    public final void addMergepointMapping(MergepointMapping mergepointMapping)
            throws ConfigurationException
    {
        throw new UnsupportedOperationException(
                "The generator " + getClass().getName()
                    + " does not support mergepoints");
    }

    @Override
    public final MergepointMapping getMergepointMapping(String name)
    {
        return null;
    }
}
