package org.apache.torque.gf.source;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * A type of a source.
 *
 * $Id: $
 */
public interface SourceType
{
    /**
     * Returns an unique key for the source type.
     *
     * @return an unique key for the source type, not null.
     */
    String getKey();

    /**
     * Gets the filename extension this source type typically has.
     *
     * @return the filename extension without leading dot,
     *         or null if no typical extension exists.
     */
    String getFilenameExtension();

    /**
     * Returns a parser for this type of source.
     *
     * @return a source parser, not null.
     */
    SourceParser getParser();
}
