package org.apache.torque.gf.source.xml;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.source.RichSourceElementImpl;
import org.apache.torque.gf.source.SourceElement;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * A SAX Handler for creating a source element tree from xml.
 */
public class XmlSourceSaxHandler extends DefaultHandler
{
    /**
     * the root element of the tree.
     */
    private SourceElement element;

    /**
     * the currently parsed element.
     */
    private SourceElement root;

    @Override
    public void startElement(String uri, String localName,
                    String qName, Attributes attributes)
            throws SAXException
    {
        SourceElement current = new RichSourceElementImpl(qName);
        for (int i = 0; i < attributes.getLength(); ++i)
        {
            current.setAttribute(
                    attributes.getQName(i), attributes.getValue(i));
        }
        if (element != null)
        {
            element.addChild(current);
        }
        else
        {
            root = current;
        }
        element = current;
    }

    @Override
    public void endElement(String uri, String localName, String qName)
            throws SAXException
    {
        element = element.getParent();
    }

    @Override
    public void characters(char[] ch, int start, int length)
            throws SAXException
    {
        String characterData = new String(ch, start, length);
        if (isWhitespace(characterData))
        {
            return;
        }
        String textContent = (String) element.getAttribute((String) null);
        if (textContent != null)
        {
            textContent = textContent + characterData;
        }
        else
        {
            textContent = characterData;
        }
        element.setAttribute((String) null, textContent);
    }

    @Override
    public void ignorableWhitespace(char[] ch, int start, int length)
            throws SAXException
    {

    }

    /**
     * returns the root element of the tree.
     *
     * @return the root element (may be null if no elements were in the xml)
     *         or null if the xml was not yet parsed.
     */
    public SourceElement getRoot()
    {
        return root;
    }

    /**
     * Checks if a String consists only of whitespace
     *
     * @param toCheck the String to check.
     *
     * @return true if the String only contains whitespace characters, false
     *         if it contains other characters..
     */
    private boolean isWhitespace(String toCheck)
    {
        for (int i = 0; i < toCheck.length(); ++i)
        {
           char ch = toCheck.charAt(i);
           if (ch != ' ' && ch != '\r' && ch != '\n' && ch != '\t')
           {
               return false;
           }
        }
        return true;
    }
}
