package org.apache.torque.gf.source.xml;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.gf.source.SourceParser;
import org.apache.torque.gf.source.SourceType;

/**
 * The source type representing an XML source.
 *
 * $Id: $
 */
public final class XmlSourceType implements SourceType
{
    /** The key for a XML source. */
    private static final String KEY = "xml";

    /** The filename extension for a XML source. */
    private static final String FILENAME_EXTENSION = "xml";

    /**
     * Returns an unique key for the source type.
     *
     * @return "xml".
     */
    public String getKey()
    {
        return KEY;
    }

    /**
     * Gets the filename extension this source type typically has.
     *
     * @return "xml".
     */
    public String getFilenameExtension()
    {
        return FILENAME_EXTENSION;
    }

    /**
     * Returns a parser for this type of source.
     *
     * @return a source parser, not null.
     */
    public SourceParser getParser()
    {
        return new XmlSourceParser();
    }

    /**
     * Returns a hash code of this instance consistent with equals..
     * As all instances of this class are equal to each other,
     * the hash code is always the same.
     *
     * @return 1.
     */
    @Override
    public int hashCode()
    {
        return 1;
    }

    /**
     * Checks whether other is equal to this instance.
     * All instances of this class are equal to each other.
     *
     * @return true if <code>other</code> is a XmlSourceType, false
     *         otherwise.
     */
    @Override
    public boolean equals(Object other)
    {
        if (other == null)
        {
            return false;
        }
        if (!other.getClass().equals(XmlSourceType.class))
        {
            return false;
        }
        return true;
    }
}
