package org.apache.torque.gf.generator.java;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import static org.junit.Assert.assertEquals;

import java.io.File;

import org.apache.torque.gf.control.ControllerState;
import org.apache.torque.gf.generator.GeneratorException;
import org.apache.torque.gf.qname.QualifiedName;
import org.junit.Before;
import org.junit.Test;

public class ModifySourcenameGeneratorTest
{
    private ModifySourcenameGenerator generator;

    private ControllerState controllerState;

    @Before
    public void setUp()
    {
        this.generator = new ModifySourcenameGenerator(new QualifiedName(
                "org.apache.torque.gf.modifySourcenameGenerator"));
        controllerState = new ControllerState();
        controllerState.setSourceFile(
                new File("src/test/some-test-file-name.someTestExtension"));
    }

    @Test
    public void testDefault() throws GeneratorException
    {
        String result = generator.execute(controllerState);
        assertEquals("some-test-file-name.someTestExtension", result);
    }

    @Test
    public void testAll() throws GeneratorException
    {
        generator.setDiscardFrom("Ext");
        generator.setDiscardTo("me-");
        generator.setPrefix("prefix-");
        generator.setSuffix("-suffix");
        String result = generator.execute(controllerState);
        assertEquals("prefix-test-file-name.someTest-suffix", result);
    }

    @Test
    public void testDiscardFrom() throws GeneratorException
    {
        generator.setDiscardFrom("-");
        String result = generator.execute(controllerState);
        assertEquals("some", result);
    }

    @Test
    public void testDiscardTo() throws GeneratorException
    {
        generator.setDiscardTo("-");
        String result = generator.execute(controllerState);
        assertEquals("name.someTestExtension", result);
    }

    @Test
    public void testOverlappingFromAndTo() throws GeneratorException
    {
        generator.setDiscardFrom("-");
        generator.setDiscardTo("-");
        String result = generator.execute(controllerState);
        assertEquals("", result);
    }

    @Test
    public void testSourceFilenameNull() throws GeneratorException
    {
        controllerState.setSourceFile(null);
        String result = generator.execute(controllerState);
        assertEquals("", result);
    }
}
