package org.apache.torque.gf.generator.java;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import static org.junit.Assert.assertEquals;

import org.apache.torque.gf.generator.GeneratorException;
import org.apache.torque.gf.qname.QualifiedName;
import org.junit.Before;
import org.junit.Test;

public class NewlineGeneratorTest
{
    private NewlineGenerator newlineGenerator;

    @Before
    public void setUp()
    {
        this.newlineGenerator = new NewlineGenerator(new QualifiedName(
                "org.apache.torque.gf.newlineGenerator"));
    }

    @Test
    public void testDefault() throws GeneratorException {
        String result = newlineGenerator.execute(null);
        assertEquals("\n", result);
    }

    @Test
    public void testWindowsStyle() throws GeneratorException {
        newlineGenerator.setWindowsStyle(true);
        String result = newlineGenerator.execute(null);
        assertEquals("\r\n", result);
    }

    @Test()
    public void testCountZero() throws GeneratorException {
        newlineGenerator.setCount(0);
        String result = newlineGenerator.execute(null);
        assertEquals("", result);
    }

    @Test(expected = GeneratorException.class)
    public void testCountLessThanZero() throws GeneratorException {
        newlineGenerator.setCount(-1);
        String result = newlineGenerator.execute(null);
        assertEquals("\n", result);
    }

    @Test()
    public void testCountFive() throws GeneratorException {
        newlineGenerator.setCount(5);
        String result = newlineGenerator.execute(null);
        assertEquals("\n\n\n\n\n", result);
    }
}
