package org.apache.torque.gf.source;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import org.apache.torque.gf.generator.GeneratorException;
import org.junit.Before;
import org.junit.Test;

public class SourcePathTest
{
    private RichSourceElementImpl root;
    private RichSourceElementImpl firstLevel;
    private RichSourceElementImpl secondLevel;
    private RichSourceElementImpl thirdLevel;

    @Before
    public void setUp()
    {
        root = new RichSourceElementImpl("root");
        root.addChild(new RichSourceElementImpl("firstLevel1"));
        firstLevel  = new RichSourceElementImpl("firstLevel2");
        root.addChild(firstLevel);
        root.addChild(new RichSourceElementImpl("firstLevel3"));
        secondLevel = new RichSourceElementImpl("secondLevel");
        firstLevel.addChild(secondLevel);
        thirdLevel = new RichSourceElementImpl("thirdLevel");
        secondLevel.addChild(thirdLevel);
    }

    @Test
    public void testGetPath() throws GeneratorException
    {
        assertEquals(
                "root/firstLevel2/secondLevel/thirdLevel",
                SourcePath.getPathAsString(thirdLevel));
    }

    @Test(expected=GeneratorException.class)
    public void testGetPathInfiniteLoop() throws GeneratorException
    {
        SourceElement loopElement1 = new RichSourceElementImpl("loopElement1");
        SourceElement loopElement2 = new RichSourceElementImpl("loopElement2");
        loopElement1.addChild(loopElement2);
        loopElement2.addChild(loopElement1);
        SourcePath.getPathAsString(loopElement1);
    }

    @Test
    public void testGetElementFromRootSingleRelativeElement()
    {
        List<SourceElement> result
                = SourcePath.getElementsFromRoot(root, "root");
        List expected = new ArrayList<SourceElement>();
        expected.add(root);
        assertEquals(expected, result);
    }

    @Test
    public void testGetElementFromRootSingleRelativeElementNoMatch()
    {
        List<SourceElement> result
                = SourcePath.getElementsFromRoot(root, "root1");
        assertEquals(0, result.size());
    }

    @Test
    public void testGetElementFromRootSingleAbsoluteElement()
    {
        List<SourceElement> result
                = SourcePath.getElementsFromRoot(root, "/root");
        List expected = new ArrayList<SourceElement>();
        expected.add(root);
        assertEquals(expected, result);
    }

    @Test
    public void testGetElementFromRootSingleAbsoluteElementNoMatch()
    {
        List<SourceElement> result
                = SourcePath.getElementsFromRoot(root, "/root1");
        assertEquals(0, result.size());
    }
}
