package org.apache.torque.gf.source.xml;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import static org.junit.Assert.assertEquals;

import java.io.File;
import java.util.ArrayList;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.torque.gf.source.FileSource;
import org.apache.torque.gf.source.RichSourceElementImpl;
import org.apache.torque.gf.source.SourceElement;
import org.apache.torque.gf.source.TransformerDefinition;
import org.junit.Test;

/**
 * Tests the SourceToXml functionality.
 *
 * $Id: $
 */
public class SourceToXmlTest
{
    @Test
    public void testSourceToXml() throws Exception
    {
        File xmlFile
            = new File("src/test/resources/org/apache/torque/gf/source/xml/source.xml");
        FileSource fileSource = new FileSource(
                new XmlSourceType(),
                xmlFile,
                null,
                null,
                new ArrayList<TransformerDefinition>());
        SourceElement rootElement = fileSource.getRootElement();

        String result = new SourceToXml().toXml(rootElement);
        String expected = FileUtils.readFileToString(new File(
                "src/test/resources/org/apache/torque/gf/source/xml/sourceToXmlResult.xml"));
        // remove license from expected file
        expected = StringUtils.substringAfterLast(expected, "-->\n\n");
        assertEquals(expected, result);
    }

    @Test
    public void testSourceToXmlWithReferences() throws Exception
    {
        File xmlFile
            = new File("src/test/resources/org/apache/torque/gf/source/xml/source.xml");
        FileSource fileSource = new FileSource(
                new XmlSourceType(),
                xmlFile,
                null,
                null,
                new ArrayList<TransformerDefinition>());
        SourceElement rootElement = fileSource.getRootElement();
        rootElement.addChild(rootElement.getChildren().get(2));

        String result = new SourceToXml().toXml(rootElement);
        String expected = FileUtils.readFileToString(new File(
                "src/test/resources/org/apache/torque/gf/source/xml/sourceToXmlWithReferenceResult.xml"));
        // remove license from expected file
        expected = StringUtils.substringAfterLast(expected, "-->\n\n");
        assertEquals(expected, result);
    }

    @Test
    public void testSourceToXmlTextEscaping() throws Exception
    {
        SourceElement rootElement = new RichSourceElementImpl("root");
        rootElement.setAttribute((String) null, "X&<>Y'\"Z");
        String result = new SourceToXml().toXml(rootElement);
        assertEquals(
                "<root id=\"1\">X&amp;&lt;&gt;Y&apo;&quot;Z</root>\n",
                result);
    }

    @Test
    public void testSourceToXmlAttributeEscaping() throws Exception
    {
        SourceElement rootElement = new RichSourceElementImpl("root");
        rootElement.setAttribute("attribute", "&<>'\"");
        String result = new SourceToXml().toXml(rootElement);
        assertEquals(
                "<root attribute=\"&amp;&lt;&gt;&apo;&quot;\" id=\"1\"/>\n",
                result);
    }

}
